ahbicht.content\_evaluation.evaluationdatatypes module
======================================================

.. automodule:: ahbicht.content_evaluation.evaluationdatatypes
   :members:
   :undoc-members:
   :show-inheritance:
